@@ -4,17 +4,17 @@ expected_table <- c(seq(0.005, 0.03, length.out = 10), 0.2, 0.15, rep(0.05, 3))
 
 set.seed(123)
 study_py <- study_py |>
-  dplyr::mutate(expected_1 = expected_table[pol_yr],
+  mutate(expected_1 = expected_table[pol_yr],
                 expected_2 = ifelse(inc_guar, 0.015, 0.03),
                 weights = rnorm(nrow(study_py), 100, 50) |> abs())
 
 exp_res <- study_py |>
-  dplyr::group_by(pol_yr, inc_guar) |>
+  group_by(pol_yr, inc_guar) |>
   exp_stats(expected = c("expected_1", "expected_2"),
             credibility = TRUE)
 
 exp_res_weighted <- study_py |>
-  dplyr::group_by(pol_yr, inc_guar) |>
+  group_by(pol_yr, inc_guar) |>
   exp_stats(expected = c("expected_1", "expected_2"),
             credibility = TRUE, wt = "weights")
 
@@ -34,3 +34,18 @@ test_that("Experience study summary method checks", {
                          credibility = TRUE, wt = "weights"),
                summary(exp_res_weighted))
 })
+
+
+toy_expo <- toy_census |> expose("2022-12-31", target_status = "Surrender") |>
+  rename(a = exposure, b = status)
+
+renamer <- c("pol_num" = "a",
+             "status" = "b",
+             "issue_date" = "c",
+             "term_date" = "d")
+toy_census2 <- toy_census |> dplyr::rename_with(\(x) renamer[x])
+
+test_that("Renaming works", {
+  expect_error(exp_stats(toy_expo))
+  expect_no_error(exp_stats(toy_expo, col_exposure = "a", col_status = "b"))
+})
